Module models

Module models 

Data types exposed by the Freedom API

Re-export of the models found in the freedom-models crate.

Structs

Account
AccountCidr
Account CIDR
AzEl
Band
Direction
IoConfiguration
LatestVersion
Data model matching return type of /api/gateway/latestVersion endpoint
Location
RegenerateResponse
Response body returned when regenerating a license key.
Satellite
The Freedom API representation of a satellite.
SatelliteConfiguration
The Freedom API representation of a satellite.
Site
SiteConfiguration
SiteHardware
Task
TaskRequest
TaskStatus
TaskStatusEvent
Tier
TwoLineElement
User
A user in freedom
UserPreferences
VerifyResponse
Response body returned from a license verification request.
View
Response body for viewing all licenses associated with an account.
ViewOne
Representation of a single license associated with an account.
WhoAmI
The data model returned from the api/users/search/whoami endpoint

Enums

BandType
IoHardware
Polarization
Status
The current status of a license.
TaskStatusType
TaskType