pub struct LatestVersion {
pub repository: String,
pub latest_tag: Version,
pub pushed_at: OffsetDateTime,
pub digest: String,
}Expand description
Data model matching return type of /api/gateway/latestVersion endpoint
Fields
repository: StringThe AWS ECR repository for Freedom Gateway
latest_tag: VersionThe semantic version of the latest tag of Freedom Gateway
pushed_at: OffsetDateTimedigest: StringTrait Implementations
Sourceimpl Clone for LatestVersion
impl Clone for LatestVersion
Sourcefn clone(&self) -> LatestVersion
fn clone(&self) -> LatestVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestVersion
impl Debug for LatestVersion
Sourceimpl<'de> Deserialize<'de> for LatestVersion
impl<'de> Deserialize<'de> for LatestVersion
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LatestVersion, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LatestVersion, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LatestVersion
Sourceimpl Hash for LatestVersion
impl Hash for LatestVersion
Sourceimpl Ord for LatestVersion
impl Ord for LatestVersion
Sourcefn cmp(&self, other: &LatestVersion) -> Ordering
fn cmp(&self, other: &LatestVersion) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LatestVersion
impl PartialEq for LatestVersion
Sourcefn eq(&self, other: &LatestVersion) -> bool
fn eq(&self, other: &LatestVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LatestVersion
impl PartialOrd for LatestVersion
Sourceimpl Serialize for LatestVersion
impl Serialize for LatestVersion
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LatestVersion