Data types exposed by the Freedom API
Re-export of the models found in the freedom-models crate.
Structs
- Account
- Account
Cidr - Account CIDR
- AzEl
- Band
- Direction
- IoConfiguration
- Latest
Version - Data model matching return type of
/api/gateway/latestVersionendpoint - Location
- Regenerate
Response - Response body returned when regenerating a license key.
- Satellite
- The Freedom API representation of a satellite.
- Satellite
Configuration - The Freedom API representation of a satellite.
- Site
- Site
Configuration - Site
Hardware - Task
- Task
Request - Task
Status - Task
Status Event - Tier
- TwoLine
Element - User
- A user in freedom
- User
Preferences - Verify
Response - Response body returned from a license verification request.
- View
- Response body for viewing all licenses associated with an account.
- ViewOne
- Representation of a single license associated with an account.
- WhoAmI
- The data model returned from the
api/users/search/whoamiendpoint
Enums
- Band
Type - IoHardware
- Polarization
- Status
- The current status of a license.
- Task
Status Type - Task
Type