pub trait GatewayApi: Api {
// Provided methods
fn get_gateway_latest_version(
&self,
) -> impl Future<Output = Result<LatestVersion, Error>> + Send + Sync { ... }
fn get_gateway_licenses(
&self,
) -> impl Future<Output = Result<View, Error>> + Send + Sync { ... }
fn get_gateway_license_by_id(
&self,
id: u32,
) -> impl Future<Output = Result<ViewOne, Error>> + Send + Sync { ... }
fn regenerate_gateway_license(
&self,
id: u32,
) -> impl Future<Output = Result<RegenerateResponse, Error>> + Send + Sync { ... }
fn verify_gateway_license(
&self,
license_key: &str,
) -> impl Future<Output = Result<VerifyResponse, Error>> + Send + Sync { ... }
}Expand description
Extension API for interacting with the Freedom Gateway licensing architecture
Provided Methods
Sourcefn get_gateway_latest_version(
&self,
) -> impl Future<Output = Result<LatestVersion, Error>> + Send + Sync
fn get_gateway_latest_version( &self, ) -> impl Future<Output = Result<LatestVersion, Error>> + Send + Sync
Fetch information about the latest version of Freedom Gateway
Sourcefn get_gateway_licenses(
&self,
) -> impl Future<Output = Result<View, Error>> + Send + Sync
fn get_gateway_licenses( &self, ) -> impl Future<Output = Result<View, Error>> + Send + Sync
Fetch full list of gateway licenses
Sourcefn get_gateway_license_by_id(
&self,
id: u32,
) -> impl Future<Output = Result<ViewOne, Error>> + Send + Sync
fn get_gateway_license_by_id( &self, id: u32, ) -> impl Future<Output = Result<ViewOne, Error>> + Send + Sync
Fetch single gateway license by ID
Sourcefn regenerate_gateway_license(
&self,
id: u32,
) -> impl Future<Output = Result<RegenerateResponse, Error>> + Send + Sync
fn regenerate_gateway_license( &self, id: u32, ) -> impl Future<Output = Result<RegenerateResponse, Error>> + Send + Sync
Regenerate a license by ID. This will create a new license key, and invalidate the previous license key associated with the gateway license ID
Sourcefn verify_gateway_license(
&self,
license_key: &str,
) -> impl Future<Output = Result<VerifyResponse, Error>> + Send + Sync
fn verify_gateway_license( &self, license_key: &str, ) -> impl Future<Output = Result<VerifyResponse, Error>> + Send + Sync
Checks whether the provided license is valid
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".